@@ -6,7 +6,7 @@
 
 struct Applet
 {
-  GtkWidget *(*Build_Objects)(); // store his objets in a static self struct
+  GtkWidget *(*Build_Objects)(gboolean, GtkWidget *); // store his objets in a static self struct
   void (*Free_Objects)(); // free all but the Gtk Widgets
   void (*Save)();
   void (*Restore)();
@@ -44,7 +44,6 @@ freedata                               (GtkWidget       *ignored,
                                         gpointer         user_data); // to free data on destroy
 
 extern struct gpe_icon my_icons[];
-extern GtkStyle *wstyle; // for pixmaps
 extern GtkWidget *mainw; // for dialogs
 
 struct fstruct
