@@ -75,14 +75,14 @@ usage()
 void initwindow()
 {
    self.w = mainw = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-   gtk_window_set_title(GTK_WINDOW(self.w),_("System Information"));
-   gtk_widget_set_usize(GTK_WIDGET(self.w),240, 310);
+   gtk_window_set_title(GTK_WINDOW(self.w), _("System Information"));
+   gtk_widget_set_usize(GTK_WIDGET(self.w), 240, 310);
 
-   gtk_signal_connect (GTK_OBJECT(self.w), "delete-event",
-		       (GtkSignalFunc) gtk_main_quit, NULL);
+   g_signal_connect (G_OBJECT(self.w), "delete-event",
+	                 G_CALLBACK(gtk_main_quit), NULL);
 
-   gtk_signal_connect (GTK_OBJECT(self.w), "destroy", 
-      (GtkSignalFunc) gtk_main_quit, NULL);
+   g_signal_connect (G_OBJECT(self.w), "destroy", 
+                     G_CALLBACK(gtk_main_quit), NULL);
 }
 
 
@@ -98,8 +98,8 @@ void make_container(int whichtab)
   GTK_WIDGET_SET_FLAGS(self.dismiss, GTK_CAN_DEFAULT);
   gtk_box_pack_start(GTK_BOX(hbuttons),self.dismiss,FALSE, TRUE, 0);
   
-  gtk_signal_connect (GTK_OBJECT(self.dismiss), "clicked",
-		      (GtkSignalFunc) Sysinfo_Free_Objects, NULL);
+  g_signal_connect (G_OBJECT(self.dismiss), "clicked",
+		      G_CALLBACK(Sysinfo_Free_Objects), NULL);
 			  
   self.applet = Sysinfo_Build_Objects(whichtab);
   gtk_container_add(GTK_CONTAINER(self.vbox),self.applet);
