@@ -102,19 +102,22 @@ play_sample(char *filename)
 }
 
 
-static gboolean 
-channel_active(const gchar *name)
+static int
+channel_active(int chan)
 {
 	int i = 0;
 	
-	if (!name) 
+	if (!mixer_names[chan]) 
 		return FALSE;
 
+	if (!((1 << chan) & devmask))
+		return FALSE;
+	
 	if (!show_channels)
 		return TRUE;
 	
 	while (show_channels[i])
-		if (!strcmp(show_channels[i++], name))
+		if (!strcmp(show_channels[i++], mixer_names[chan]))
 			return TRUE;
 		
 	return (FALSE);
@@ -165,27 +168,36 @@ sound_load_settings(void)
 	{
 		int nc = -1, val = -1, ret;
 		char buf[128];
+		
+		memset(buf, 0, 128);
+		
 		while (fgets(buf, 128, cfgfile))
 		{
 			ret = sscanf(buf, "muted %d", &nc);
 			if (ret)
 				muted = nc;
 			
-			ret = sscanf(buf, "%d %d", &nc, &val);			
+			ret = sscanf(buf, "%d %d", &nc, &val);		
+			
+			memset(buf, 0, 128);
 			if ((ret == 2) && (nc >= 0) && (nc <= SOUND_MIXER_NRDEVICES))
 			{
-				if (muted)
+				if (channel_active(mchannels[nc].nr) && !(nc && !mchannels[nc].nr))
 				{
-					set_volume(mchannels[nc].nr, 0);
-					mchannels[nc].backupval = val;
-					mchannels[nc].value = val;
+					if (muted)
+					{
+						set_volume(mchannels[nc].nr, 0);
+						mchannels[nc].backupval = val;
+						mchannels[nc].initval = val;
+						mchannels[nc].value = val;
+					}
+					else
+					{
+						mchannels[nc].value = val;
+						mchannels[nc].initval = val;
+						set_volume(mchannels[nc].nr, val);
+					}
 				}
-				else
-				{
-					mchannels[nc].value = val;
-					set_volume(mchannels[nc].nr, val);
-				}
-	
 			}
 		}
 		fclose(cfgfile);
@@ -222,10 +234,13 @@ sound_restore_settings(void)
 	if (!initialized)
 		return;
 		
-	for (i = 0; i < SOUND_MIXER_NRDEVICES; i++)
+	for (i = 0; i < active_channels; i++)
 	{
-		mchannels[i].value = mchannels[i].initval;
-		set_volume(mchannels[i].nr, mchannels[i].value);
+		if (channel_active(mchannels[i].nr))
+		{
+			mchannels[i].value = mchannels[i].initval;
+			set_volume(mchannels[i].nr, mchannels[i].value);
+		}
 	}
 }
 
@@ -274,7 +289,7 @@ sound_init(void)
 		
 	for (i = 0; i < SOUND_MIXER_NRDEVICES; i++)
 	{
-		if (((1 << i) & devmask) && channel_active(mixer_names[i])) 
+		if (/*((1 << i) & devmask)*/channel_active(i))
 		{
 			mchannels[active_channels].nr = i; /* channel number */
 			if (i) /* name and label */
